@@ -43,13 +43,13 @@ glm::vec4 parseColor( std::string value ) {
             value = value.substr(sz+1);
             found[3] = std::stof(value,&sz);
             if ( value.size() != sz ) {
-                throw "dur";
+                throw std::runtime_error("dur");
             }
         } else {
             found[3] = 1;
         }
     } catch ( ... ) {
-        throw new std::invalid_argument("Unable to parse value `" + valuecopy + "` as a color. Should be in the format r,g,b or r,g,b,a. Like 1,1,1,1.");
+        throw std::invalid_argument("Unable to parse value `" + valuecopy + "` as a color. Should be in the format r,g,b or r,g,b,a. Like 1,1,1,1.");
     }
     return found;
 }
@@ -102,7 +102,7 @@ SlopOptions* getOptions( cxxopts::Options& options ) {
     if ( options.count( "nodecorations" ) > 0 ) {
         foo->nodecorations = options["nodecorations"].as<int>();
         if ( foo->nodecorations < 0 || foo->nodecorations > 2 ) {
-            throw new std::invalid_argument( "--nodecorations must be between 0 and 2. Or be used as a flag." );
+            throw std::invalid_argument( "--nodecorations must be between 0 and 2. Or be used as a flag." );
         }
     }
     return foo;
@@ -113,7 +113,7 @@ std::string formatOutput( std::string input, SlopSelection selection ) {
     for( unsigned int i=0;i<input.length();i++) {
         if ( input[i] == '%' ) {
             if ( input.length() <= i+1 ) {
-                throw new std::invalid_argument( "Expected character after `%`, got END." );
+                throw std::invalid_argument( "Expected character after `%`, got END." );
             }
             switch( input[i+1] ) {
                 case 'x':
@@ -132,7 +132,7 @@ std::string formatOutput( std::string input, SlopSelection selection ) {
                 case 'i':
                 case 'I': output << selection.id; break;
                 case '%': output << "%"; break;
-                default: throw new std::invalid_argument( std::string()+"Expected x, y, w, h, g, i, c, or % after % in format. Got `" + input[i+1] + "`." );
+                default: throw std::invalid_argument( std::string()+"Expected x, y, w, h, g, i, c, or % after % in format. Got `" + input[i+1] + "`." );
              }
             i++;
             continue;
@@ -191,8 +191,12 @@ void printHelp() {
     std::cout << "  -r, --shader=STRING           Sets the shader to load and use from\n";
     std::cout << "                                  ~/.config/slop/\n";
     std::cout << "  -f, --format=STRING           Set the output format string. Format specifiers\n";
-    std::cout << "                                  are %x, %y, %w, %h, %i, %g, and %c.\n";
-    std::cout << "                                  (default=`%g\n')\n";
+    std::cout << "                                  are %x (x offset), %y (y offset), %w (width),\n";
+    std::cout << "                                  %h (height), %i (window id),\n";
+    std::cout << "                                  %g (geometry - `%wx%h+%x+%y\'),\n";
+    std::cout << "                                  %c (1 if cancelled, 0 otherwise),\n";
+    std::cout << "                                  and %% for a literal percent sign.\n";
+    std::cout << "                                  (default=`%g')\n";
     std::cout << "  -o, --noopengl                Disable graphics acceleration.\n";
     std::cout << "Examples\n";
     std::cout << "    $ # Gray, thick, transparent border for maximum visiblity.\n";
@@ -230,7 +234,7 @@ int app( int argc, char** argv ) {
     ("t,tolerance", "How far in pixels the mouse can move after clicking, and still be detected as a normal click instead of a click-and-drag. Setting this to 0 will disable window selections. Alternatively setting it to 9999999 would force a window selection.", cxxopts::value<float>())
     ("c,color", "Sets  the  selection  rectangle's  color.  Supports  RGB or RGBA input. Depending on the system's window manager/OpenGL  support, the opacity may be ignored.", cxxopts::value<std::string>())
     ("r,shader", "This  sets  the  vertex shader, and fragment shader combo to use when drawing the final framebuffer to the screen. This obviously only  works  when OpenGL is enabled. The shaders are loaded from ~/.config/maim. See https://github.com/naelstrof/slop for more information on how to create your own shaders.", cxxopts::value<std::string>())
-    ("n,nodecorations", "Sets the level of aggressiveness when trying to remove window decroations. `0' is off, `1' will try lightly to remove decorations, and `2' will recursively descend into the root tree until it gets the deepest available visible child under the mouse. Defaults to `0'.", cxxopts::value<int>()->implicit_value("1"))
+    ("n,nodecorations", "Sets the level of aggressiveness when trying to remove window decorations. `0' is off, `1' will try lightly to remove decorations, and `2' will recursively descend into the root tree until it gets the deepest available visible child under the mouse. Defaults to `0'.", cxxopts::value<int>()->implicit_value("1"))
     ("l,highlight", "Instead of outlining a selection, maim will highlight it instead. This is particularly useful if the color is set to an opacity lower than 1.")
     ("q,quiet", "Disable any unnecessary cerr output. Any warnings or info simply won't print.")
     ("k,nokeyboard", "Disables the ability to cancel selections with the keyboard.")
@@ -242,7 +246,7 @@ int app( int argc, char** argv ) {
     // Options just validates all of our input from argv
     auto& positional = options["positional"].as<std::vector<std::string>>();
     if ( positional.size() > 0 ) {
-        throw new std::invalid_argument("Unexpected positional argument: " + positional[0]);
+        throw std::invalid_argument("Unexpected positional argument: " + positional[0]);
     }
     bool help = false;
     if ( options.count( "help" ) > 0 ) {
@@ -297,8 +301,8 @@ int app( int argc, char** argv ) {
 int main( int argc, char** argv ) {
     try {
         return app( argc, argv );
-    } catch( std::exception* e ) {
-        std::cerr << "Slop encountered an error:\n" << e->what() << "\n";
+    } catch( std::exception& e ) {
+        std::cerr << "Slop encountered an error:\n" << e.what() << "\n";
         return 1;
     } // let the operating system handle any other kind of exception.
     return 1;
